-- author: DD ModPassion
-- copyright (C): DD ModPassion, All Rights Reserved
-- version: Farming Simulator 25
BaleTwineAddon = {SPEC_NAME = g_currentModName..".baleTwineAddon"}
local modName = g_currentModName
function BaleTwineAddon.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Baler, specializations)
end
function BaleTwineAddon.registerEventListeners(vehicleType)
    SpecializationUtil.registerEventListener(vehicleType, "onLoad", BaleTwineAddon)
    SpecializationUtil.registerEventListener(vehicleType, "onChangedFillType", BaleTwineAddon)
end
function BaleTwineAddon:onLoad(savegame)
    if self.spec_baler ~= nil and not self.spec_baler.isRoundBaler then
        self.spec_baleTwineAddon = self["spec_"..BaleTwineAddon.SPEC_NAME]
        local spec = self.spec_baleTwineAddon
        spec.variationId = "TWINE"
        spec.baleTwineFillUnit = 0
        for i = 1, #self.spec_fillUnit.fillUnits do
            if self:getFillUnitAllowsFillType(i, FillType.BALE_TWINE) then
                spec.baleTwineFillUnit = i
            end
        end
    else
        SpecializationUtil.removeEventListener(self, "onChangedFillType", BaleNetAddon)
    end
end
function BaleTwineAddon:onChangedFillType(fillUnitIndex, fillTypeIndex, oldFillTypeIndex)
	local spec = self.spec_baler
	if fillUnitIndex == spec.fillUnitIndex or fillUnitIndex == spec.buffer.fillUnitIndex then
		local mainFillTypeIndex = self:getFillUnitFillType(spec.fillUnitIndex)
		if mainFillTypeIndex == FillType.UNKNOWN then
			mainFillTypeIndex = fillTypeIndex
		end
		if mainFillTypeIndex ~= FillType.UNKNOWN then
			local baleTypeDef = spec.baleTypes[spec.currentBaleTypeIndex]
			spec.currentBaleTypeDefinition = baleTypeDef
            if not self.spec_baler.isRoundBaler then
                if self.spec_consumable.types[1].consumingVariationIndex ~= nil then
                    self.spec_baleTwineAddon.variationId = string.sub(g_consumableManager:getConsumableVariationNameByIndex(self.spec_consumable.types[1].consumingVariationIndex), 32)
                end
            end
			spec.currentBaleXMLFilename, spec.currentBaleIndex = g_baleManager:getBaleXMLFilename(mainFillTypeIndex, baleTypeDef.isRoundBale, baleTypeDef.width, baleTypeDef.height, baleTypeDef.length, baleTypeDef.diameter, self.customEnvironment)
			local baleCapacity = g_baleManager:getBaleCapacityByBaleIndex(spec.currentBaleIndex, mainFillTypeIndex)
			if fillUnitIndex == spec.fillUnitIndex then
				self:setFillUnitCapacity(fillUnitIndex, baleCapacity, false)
			elseif spec.buffer.capacityPercentage ~= nil then
				self:setFillUnitCapacity(fillUnitIndex, baleCapacity * spec.buffer.capacityPercentage, false)
			end
			ObjectChangeUtil.setObjectChanges(baleTypeDef.changeObjects, true, self, self.setMovingToolDirty)
			if spec.currentBaleXMLFilename == nil then
				Logging.warning("Could not find bale for given bale type definition \'%s\'", baleTypeDef.index)
			end
		end
	end
end
function BaleTwineAddon:updateDebugValues(values)
    if not self.spec_baler.isRoundBaler then
        local spec = self.spec_baleTwineAddon
        table.insert(values, {name = "baleTwineFillUnit", value = string.format("base %.0f with color %s", spec.baleTwineFillUnit, spec.variationId)})
    end
end